package scala.maven;

import java.io.File;
import java.io.IOException;
import java.util.List;

/**
 * Abstract parent of all Scala Mojo
 */
public abstract class ScalaCompilerSupport extends ScalaMojoSupport {

    abstract protected File getOutputDir() throws Exception;
    abstract protected File getSourceDir() throws Exception;
    abstract protected List<String> getClasspathElements() throws Exception;

    @Override
    protected final void doExecute() throws Exception {
        File outputDir = getOutputDir();
        if (!outputDir.exists()) {
            outputDir.mkdirs();
        }

        File sourceDir = getSourceDir();
        try {
            sourceDir = sourceDir.getCanonicalFile();
        } catch (IOException exc) {
            sourceDir = sourceDir.getAbsoluteFile();
        }
        if (!sourceDir.exists()) {
            return;
        }
        String[] sourceFiles = JavaCommand.findFiles(sourceDir, "**/*.scala");
        if (sourceFiles.length == 0) {
            getLog().warn("No source files found.");
            return;
        }

        JavaCommand jcmd = getScalaCommand();
        jcmd.addArgs("-classpath", JavaCommand.toMultiPath(getClasspathElements()));
        jcmd.addArgs("-d", outputDir.getAbsolutePath());
        jcmd.addArgs("-sourcepath", sourceDir.getAbsolutePath());
        for (String x : sourceFiles) {
            jcmd.addArgs(sourceDir + File.separator + x);
        }
        jcmd.run(displayCmd);
    }
}
